metaXpara-class: An S4 class to represent the parameters and data for data processing
Description
An S4 class to represent the parameters and data for data processing
Value
A object of metaXpara
Slots
dir.case- The path names of the NetCDF/mzXML files to read
dir.ctrl- The path names of the NetCDF/mzXML files to read
sampleListFile- The file name of containing the experiment design
sampleList- A data.frame containing the experiment design
ratioPairs- A character containing the ratio pairs, such as "A:B;A:C"
missValueImputeMethod- A character of missing value imputation method
sampleListHead- The name of head of
sampleListFile outdir- The output directory
prefix- The prefix of output file
xcmsPeakListFile- The file of output from XCMS
fig- A
list of file names of figures peaksData- A
data.frame containing the peaks data VIP- A
data.frame containing the VIP rawPeaks- A
data.frame containg the raw peaks data xcmsSetObj- An object of
xcmsSet quant- A
data.frame containing the quantification result idres- A
data.frame containing the identification result xcmsSet.method- Method to use for peak detection. See details
findPeaks in package XCMS xcmsSet.ppm- The maxmial tolerated m/z deviation in consecutive scans,
in ppm (parts per million)
xcmsSet.peakwidth- Chromatographic peak width, given as
range (min,max) in seconds
xcmsSet.snthresh- The signal to noise ratio cutoff, definition see
findPeaks.centWave xcmsSet.prefilter- prefilter=c(k,I),
see
findPeaks.centWave xcmsSet.mzCenterFun- See
findPeaks.centWave xcmsSet.integrate- See
findPeaks.centWave xcmsSet.mzdiff- See
findPeaks.centWave xcmsSet.noise- See
findPeaks.centWave xcmsSet.verbose.columns- See
findPeaks.centWave xcmsSet.polarity- Filter raw data for positive/negative scans.
See
xcmsSet xcmsSet.profparam- Parameters to use for profile generation.
See
xcmsSet xcmsSet.nSlaves- The number of slaves/cores to be used for parallel
peak detection. See
xcmsSet xcmsSet.fitgauss- See
findPeaks.centWave xcmsSet.sleep- The number of seconds to pause between plotting
peak finding cycles. See
findPeaks.centWave xcmsSet.fwhm- See
findPeaks.matchedFilter xcmsSet.max- See
findPeaks.matchedFilter xcmsSet.step- See
findPeaks.matchedFilter group.bw0- See
group.density group.mzwid0- See
group.density group.bw- See
group.density group.mzwid- See
group.density group.minfrac- See
group.density group.minsamp- See
group.density group.max- See
group.density group.sleep- See
group.density retcor.method- See
retcor retcor.profStep- See
retcor.obiwarp retcor.plottype- See
retcor.obiwarp qcRlscSpan- The value of span for QC-RLSC